# -*- coding: utf-8 -*-
                           #!/usr/bin/env python
# -*- coding: utf-8 -*-
from PyQt4.QtCore import QCoreApplication, Qt
from PyQt4.QtGui import QApplication
from soundstub import MainWindow

if __name__ == "__main__":
    import sys
    #gobject.threads_init()
    app = QApplication(sys.argv)
    QCoreApplication.flush()
    ui = MainWindow()
    ui.setAttribute(Qt.WA_Maemo5StackedWindow)
    ui.showFullScreen()
    sys.exit(app.exec_())
